# Linear operators

> *Definition 1*: a **linear operator** $T$ is a linear mapping such that
>
> 1. the domain $\mathscr{D}(T)$ of $T$ is a vector space and the range $\mathscr{R}(T)$ of $T$ is contained in a vector space over the same field as $\mathscr{D}(T)$.
> 2. $\forall x, y \in \mathscr{D}(T): T(x + y) = Tx + Ty$.
> 3. $\forall x \in \mathscr{D}(T), \alpha \in F: T(\alpha x) = \alpha Tx$.

Observe the notation; we $Tx$ and $T(x)$ are equivalent, most of the time. 

> *Definition 2*: let $\mathscr{N}(T)$ be the **null space** of $T$ defined as
>
> $$
>   \mathscr{N}(T) = \{x \in \mathscr{D}(T) \;|\; Tx = 0\}.
> $$

We have the following properties.

> *Proposition 1*: let $T$ be a linear operator, then
>
> 1. $\mathscr{R}(T)$ is a vector space,
> 2. $\mathscr{N}(T)$ is a vector space,
> 3. if $\dim \mathscr{D}(T) = n \in \mathbb{N}$ then $\dim \mathscr{R}(T) \leq n$.

??? note "*Proof*:"

    Will be added later.

An immediate consequence of statement 3 is that linear operators preserve linear dependence.

> *Proposition 2*: let $Y$ be a vector space, a linear operator $T: \mathscr{D}(T) \to Y$ is injective if 
>
> $$
>   \forall x_1, x_2 \in \mathscr{D}(T): Tx_1 = Tx_2 \implies x_1 = x_2.
> $$

??? note "*Proof*:"

    Will be added later.

Injectivity of $T$ is equivalent to $\mathscr{N}(T) = \{0\}$. 

??? note "*Proof*:"

    Will be added later.

> *Theorem 1*: if a linear operator $T: \mathscr{D}(T) \to \mathscr{R}(T)$ is injective there exists a mapping $T^{-1}: \mathscr{R}(T) \to \mathscr{D}(T)$ such that
>
> $$
>   y = Tx \iff T^{-1} y = x,
> $$
>
> for all $x \in \mathscr{D}(T)$, denoted as the **inverse operator**.

??? note "*Proof*:"

    Will be added later.

> *Proposition 3*: let $T: \mathscr{D}(T) \to \mathscr{R}(T)$ be an injective linear operator, if $\mathscr{D}(T)$ is finite-dimensional, then 
> 
> $$
>   \dim \mathscr{D}(T) = \dim \mathscr{R}(T).
> $$ 

??? note "*Proof*:"

    Will be added later.

> *Lemma 1*: let $X,Y$ and $Z$ be vector spaces and let $T: X \to Y$ and $S: Y \to Z$ be injective linear operators, then $(ST)^{-1}: Z \to X$ exists and 
>
> $$
>   (ST)^{-1} = T^{-1} S^{-1}.
> $$

??? note "*Proof*:"

    Will be added later.

We finish this subsection with a definition of the space of linear operators.

> *Definition 3*: let $\mathscr{L}(X,Y)$ denote the set of linear operators mapping from a vector space $X$ to a vector space $Y$. 

From this definition the following theorem follows.

> *Theorem 2*: let $X$ and $Y$ be vectors spaces, the set of linear operators $\mathscr{L}(X,Y)$ is a vector space.

??? note "*Proof*:"

    Will be added later.

Therefore, we may also call $\mathscr{L}(X,Y)$ the space of linear operators.

## Bounded linear operators

> *Definition 4*: let $(X, \|\cdot\|_X)$ and $(Y,\|\cdot\|_Y)$ be normed spaces over a field $F$ and let $T: \mathscr{D}(T) \to Y$ be a linear operator with $\mathscr{D}(T) \subset X$. Then $T$ is a **bounded linear operator** if
>
> $$
>   \exists c \in F \forall x \in \mathscr{D}(T): \|Tx\|_Y \leq c \|x\|_X.
> $$

In this case we may also define the set of all bounded linear operators.

> *Definition 5*: let $\mathscr{B}(X,Y)$ denote the set of bounded linear operators mapping from a vector space $X$ to a vector space $Y$.

We have the following theorem.

> *Theorem 3*: let $X$ and $Y$ be vectors spaces, the set of bounded linear operators $\mathscr{B}(X,Y)$ is a subspace of $\mathscr{L}(X,Y)$. 

??? note "*Proof*:"

    Will be added later.

Likewise, we may call $\mathscr{B}(X,Y)$ the space of bounded linear operators.

The smallest possible $c$ such that the statement in definition 4 still holds is denoted as the norm of $T$ in the following definition.

> *Definition 5*: the norm of a bounded linear operator $T \in \mathscr{B}(X,Y)$ is defined by 
>
> $$
>   \|T\|_{\mathscr{B}} = \sup_{x \in \mathscr{D}(T) \backslash \{0\}} \frac{\|Tx\|_Y}{\|x\|_X},
> $$
>
> with $X$ and $Y$ vector spaces.

The operator norm makes $\mathscr{B}$ into a normed space.

> *Lemma 2*: let $X$ and $Y$ be normed spaces, the norm of a bounded linear operator $T \in \mathscr{B}(X,Y)$ may be given by
>
> $$
>   \|T\|_\mathscr{B} = \sup_{\substack{x \in \mathscr{D}(T) \\ \|x\|_X = 1}} \|Tx\|_Y,
> $$
>
> and the norm of a bounded linear operator is a norm. 

??? note "*Proof*:"

    Will be added later.

Note that the second statement in lemma 2 is non trivial, as the norm of a bounded linear operator is only introduced by a definition. 

> *Proposition 4*: if $(X, \|\cdot\|)$ is a finite-dimensional normed space, then every linear operator on $X$ is bounded.

??? note "*Proof*:"

    Will be added later.

By linearity of the linear operators we have the following.

> *Theorem 4*: let $X$ and $Y$ be normed spaces and let $T: \mathscr{D}(T) \to Y$ be a linear operator with $\mathscr{D}(T) \subset X$. Then the following statements are equivalent
>
> 1. $T$ is bounded,
> 2. $T$ is continuous in $\mathscr{D}(T)$,
> 3. $T$ is continuous in a point in $\mathscr{D}(T)$. 

??? note "*Proof*:"

    Will be added later.

> *Corollary 1*: let $T \in \mathscr{B}$ and let $(x_n)_{n \in \mathbb{N}}$ be a sequence in $\mathscr{D}(T)$, then we have that
>
> 1. $x_n \to x \in \mathscr{D}(T) \implies Tx_n \to Tx$ as $n \to \infty$,
> 2. $\mathscr{N}(T)$ is closed. 

??? note "*Proof*:"

    Will be added later.

Furthermore, bounded linear operators have the property that 

$$
    \|T_1 T_2\| \leq \|T_1\| \|T_2\|,
$$

for $T_1, T_2 \in \mathscr{B}$. 

??? note "*Proof*:"

    Will be added later.

> *Theorem 5*: if $X$ is a normed space and $Y$ is a Banach space, then $\mathscr{B}(X,Y)$ is a Banach space.

??? note "*Proof*:"

    Will be added later.

> *Definition 6*: let $T_1, T_2 \in \mathscr{L}$ be linear operators, $T_1$ and $T_2$ are **equal** if and only if
>
> 1. $\mathscr{D}(T_1) = \mathscr{D}(T_2)$,
> 2. $\forall x \in \mathscr{D}(T_1) : T_1x = T_2x$.

## Restriction and extension

> *Definition 7*: the **restriction** of a linear operator $T \in \mathscr{L}$ to a subspace $A \subset \mathscr{D}(T)$, denoted by $T|_A: A \to \mathscr{R}(T)$ is defined by
>
> $$
>   T|_A x = Tx,
> $$
>
> for all $x \in A$.

Furthermore.

> *Definition 8*: the **extension** of a linear operator $T \in \mathscr{L}$ to a vector space $M$ is an operator denoted by $\tilde T: M \to \mathscr{R}(T)$ such that
>
> $$
>   \tilde T|_{\mathscr{D}(T)} = T.
> $$

Which implies that $\tilde T x = Tx\; \forall x \in \mathscr{D}(T)$. Hence, $T$ is the resriction of $\tilde T$.

> *Theorem 6*: let $X$ be a normed space and let $Y$ be Banach space. Let $T \in \mathscr{B}(M,Y)$ with $A \subset X$, then there exists an extension $\tilde T: \overline M \to Y$, with $\tilde T$ a bounded linear operator and $\| \tilde T \| = \|T\|$. 

??? note "*Proof*:"

    Will be added later.