# Normed spaces

> *Definition 1*: a vector space $X$ is a **normed space** if a norm $\| \cdot \|: X \to F$ is defined on $X$, satisfying
>
> 1. $\forall x \in X: \|x\| \geq 0$,
> 2. $\|x\| = 0 \iff x = 0$,
> 3. $\forall x \in X, \alpha \in F: \|\alpha x\| = |\alpha| \|x\|$,
> 4. $\forall x, y \in X: \|x + y\| \leq \|x\| + \|y\|$.

Also called a *normed vector space* or *normed linear space*. 

> *Proposition 1*: a norm on a vector space $X$ defines a metric $d$ on $X$ given by
>
> $$
>   d(x,y) = \|x - y\|,
> $$
>
> for all $x, y \in X$ and is called a **metric induced by the norm**.

??? note "*Proof*:"

    Will be added later.

Furthermore, there is a category of normed spaces with interesting properties which is given in the following definition.

> *Definition 2*: a **Banach space** is a complete normed space with its metric induced by the norm. 

If we define the norm $\| \cdot \|$ of the Euclidean vector space $\mathbb{R}^n$ by

$$
    \|x\| = \sqrt{\sum_{j=1}^n |x(j)|^2},
$$

for all $x \in \mathbb{R}^n$, then it yields the metric

$$
    d(x,y) = \|x - y\| = \sqrt{\sum_{j=1}^n |x(j) - y(j)|^2},
$$

for all $x, y \in \mathbb{R}^n$ which imposes completeness. Therefore $(\mathbb{R}^n, \|\cdot\|)$ is a Banach space.

This adaptation also works for $C$, $l^p$ and $l^\infty$, obviously. Obtaining that $\mathbb{R}^n$, $C$, $l^p$ and $l^\infty$ are all Banach spaces.

> *Lemma 1*: a metric $d$ induced by a norm on a normed space $(X, \|\cdot\|)$ satisfies
>
> 1. $\forall x, y \in X, \alpha \in F: d(x + \alpha, y + \alpha) = d(x,y)$,
> 2. $\forall x, y \in X, \alpha \in F: d(\alpha x, \alpha y) = |\alpha| d(x,y)$.

??? note "*Proof*:"

    We have

    $$
        d(x + \alpha, y + \alpha) = \|x + \alpha - (y + \alpha)\| = \|x - y\| = d(x,y),
    $$

    and

    $$
        d(\alpha x, \alpha y) = \|\alpha x - \alpha y\| = |\alpha| \|x - y\| = |\alpha| d(x,y).
    $$

By definition, a subspace $M$ of a normed space $X$ is a subspace of $X$ with its norm induced by the norm on $X$. 

> *Definition 3*: let $M$ be a subspace of a normed space $X$, if $M$ is closed then $M$ is a **closed subspace** of $X$. 

By definition, a subspace $M$ of a Banach space $X$ is a subspace of $X$ as a normed space. Hence, we do not require $M$ to be complete.

> *Theorem 1*: a subspace $M$ of a Banach space $X$ is complete if and only if $M$ is a closed subspace of $X$.

??? note "*Proof*:"

    Will be added later.

Convergence in normed spaces follows from the definition of convergence in metric spaces and the fact that the metric is induced by the norm. 

## Convergent series

> *Definition 4*: let $(x_k)_{k \in \mathbb{N}}$ be a sequence in a normed space $(X, \|\cdot\|)$. We define the sequence of partial sums $(s_n)_{n \in \mathbb{N}}$ by 
>
> $$
>   s_n = \sum_{k=1}^n x_k,
> $$
>
> if $s_n$ converges to $s \in X$, then
>
> $$
>   \lim_{n \to \infty} \sum_{k=1}^n x_k, 
> $$
>
> is convergent, and $s$ is the sum of the series, writing
>
> $$
>   s = \lim_{n \to \infty} \sum_{k=1}^n x_k = \sum_{k=1}^\infty x_k = \lim_{n \to \infty } s_n.
> $$
>
> If the series 
>
> $$
>   \sum_{k=1}^\infty \|x_k\|,
> $$
>
> is convergent in $F$, then the series is **absolutely convergent**.

From the notion of absolute convergence the following theorem may be posed.

> *Theorem 2*: absolute convergence of a series implies convergence if and only if $(X, \|\cdot\|)$ is complete.

??? note "*Proof*:"

    Will be added later.

## Schauder basis

> *Definition 5*: let $(X, \|\cdot\|)$ be a normed space and let $(e_k)_{k \in \mathbb{N}}$ be a sequence of vectors in $X$, such that for every $x \in X$ there exists a unique sequence of scalars $(\alpha_k)_{k \in \mathbb{N}}$ such that
>
> $$
>   \lim_{n \to \infty} \|x - \sum_{k=1}^n \alpha_k e_k\| = 0,
> $$
>
> then $(e_k)_{k \in \mathbb{N}}$ is a **Schauder basis* of $(X, \|\cdot\|)$.

The expansion of a $x \in X$ with respect to a Schauder basis $(e_k)_{k \in \mathbb{N}}$ is given by

$$
    x = \sum_{k=1}^\infty \alpha_k e_k.
$$

> *Lemma 2*: if a normed space has a Schauder basis then it is seperable.

??? note "*Proof*:"

    Will be added later.

## Completion

> *Theorem 3*: for every normed space $(X, \|\cdot\|_X)$ there exists a Banach space $(Y, \|\cdot\|_Y)$ that contains a subspace $W$ that satisfies the following conditions
>
> 1. $W$ is a normed space isometric with $X$. 
> 2. $W$ is dense in $Y$.

??? note "*Proof*:"

    Will be added later.

The Banach space $(Y, \|\cdot\|_Y)$ is unique up to isometry.

## Finite dimension

> *Lemma 3*: let $\{x_k\}_{k=1}^n$ with $n \in \mathbb{N}$ be a linearly independent set of vectors in a normed space $(X, \|\cdot\|)$, then there exists a $c > 0$ such that
>
> $$
>   \Big\| \sum_{k=1}^n \alpha_k x_k \Big\| \geq c \sum_{k=1}^n |\alpha_k|,
> $$
>
> for all $\{\alpha_k\}_{k=1}^n \in F$.

??? note "*Proof*:"

    Will be added later.

As a first application of this lemma, let us prove the following.

> *Theorem 4*: every finite-dimensional subspace $M$ of a normed space $(X, \|\cdot\|)$ is complete. 

??? note "*Proof*:"

    Will be added later.

In particular, every finite dimensional normed space is complete.

> *Proposition 2*: every finite-dimensional subspace $M$ of a normed space $(X, \|\cdot\|)$ is a closed subspace of $X$. 

??? note "*Proof*:"

    Will be added later.

Another interesting property of finite-dimensional vector space $X$ is that all norms on $X$ lead to the same topology for $X$. That is, the open subsets of $X$ are the same, regardless of the particular choice of a norm on $X$. The details are as follows.

> *Definition 6*: a norm $\|\cdot\|_1$ on a vector space $X$ is **equivalent** to a norm $\|\cdot\|_2$ on $X$ if there exists $a,b>0$ such that
>
> $$
>   \forall x \in X: a \|x\|_1 \leq \|x\|_2 \leq b \|x\|_1.
> $$

This concept is motivated by the following proposition.

> *Proposition 3*: equivalent norms on $X$ define the same topology for $X$.

??? note "*Proof*:"

    Will be added later.

Using lemma 3 we may now prove the following theorem.

> *Theorem 5*: on a finite dimensional vector space $X$ any norm $\|\cdot\|_1$ is equivalent to any other norm $\|\cdot\|_2$. 

??? note "*Proof*:"

    Will be added later.

This theorem is of considerable importance. For instance, it implies that convergence or divergence of a sequence in a finite dimensional vector space does not depend on the particular choice of a norm on that space.